Documentation
¶
Overview ¶
Package text provides utilities for normalising and sanitising strings that are commonly needed when generating text or HTML content.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Normalize ¶
Normalize removes excess whitespace from the provided string. Each line is trimmed and empty lines are removed to avoid Markdown formatting mismatches.
func SanitizeToCamelCase ¶
SanitizeToCamelCase sanitizes a string and converts it to camel case for use as an HTML ID.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.